==> gmssl-tomcat-plugin-v8.5.9-0.1.1-sources.jar: com/xdja/pki/gmssl/tomcat/plugin/XDJAJSSEUtil.java <==
package com.xdja.pki.gmssl.tomcat.plugin;

import org.apache.juli.logging.Log;
import org.apache.juli.logging.LogFactory;
import org.apache.tomcat.util.file.ConfigFileLoader;
import org.apache.tomcat.util.net.SSLContext;
import org.apache.tomcat.util.net.SSLHostConfig;
import org.apache.tomcat.util.net.SSLHostConfigCertificate;
import org.apache.tomcat.util.net.SSLUtil;
import org.apache.tomcat.util.res.StringManager;
import org.bouncycastle.jsse.provider.XDJAJsseProvider;

import javax.net.ssl.*;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.security.KeyStore;
import java.security.NoSuchAlgorithmException;
import java.security.NoSuchProviderException;
import java.util.List;

public class XDJAJSSEUtil implements SSLUtil {

    private static final Log log = LogFactory.getLog(XDJAJSSEUtil.class);
    private static final StringManager sm = StringManager.getManager(XDJAJSSEUtil.class);

    private final SSLHostConfigCertificate certificate;
    private final SSLHostConfig sslHostConfig;

    public XDJAJSSEUtil(SSLHostConfigCertificate certificate) {
        this.certificate = certificate;
        this.sslHostConfig = certificate.getSSLHostConfig();
    }

    @Override
    public SSLContext createSSLContext(List<String> negotiableProtocols) throws NoSuchAlgorithmException, NoSuchProviderException {
        return new XDJAJSSEGMSSLContext(sslHostConfig.getSslProtocol());
    }


    @Override
    public KeyManager[] getKeyManagers() throws Exception {
        String password = this.certificate.getCertificateKeystorePassword();

        KeyStore ks = getStore(
                this.certificate.getCertificateKeystoreType(),
                this.certificate.getCertificateKeystoreProvider(),
                this.certificate.getCertificateKeystoreFile(),
                password
        );

        KeyManagerFactory keyMgrFact = KeyManagerFactory.getInstance("PKIX", XDJAJsseProvider.PROVIDER_NAME);
        keyMgrFact.init(ks, password.toCharArray());

        return keyMgrFact.getKeyManagers();
    }


    @Override
    public TrustManager[] getTrustManagers() throws Exception {
        KeyStore ts = getStore(
                this.sslHostConfig.getTruststoreType(),
                this.sslHostConfig.getTruststoreProvider(),
                this.sslHostConfig.getTruststoreFile(),
                this.sslHostConfig.getTruststorePassword()
        );

        TrustManagerFactory trustMgrFact = TrustManagerFactory.getInstance("PKIX", XDJAJsseProvider.PROVIDER_NAME);
        trustMgrFact.init(ts);

        return trustMgrFact.getTrustManagers();
    }

    /*
     * Gets the key- or truststore with the specified type, path, and password.
     */
    private KeyStore getStore(String type, String provider, String path, String pass) throws IOException {
        KeyStore ks = null;
        InputStream in = null;
        try {
            if (provider == null) {
                ks = KeyStore.getInstance(type);
            } else {
                ks = KeyStore.getInstance(type, provider);
            }
            in = ConfigFileLoader.getInputStream(path);
            char[] storePass = null;
            if (pass != null && !"".equals(pass)) {
                storePass = pass.toCharArray();
            }
            ks.load(in, storePass);

        } catch (FileNotFoundException fnfe) {
            log.error(sm.getString("jsse.keystore_load_failed", type, path,
                    fnfe.getMessage()), fnfe);
            throw fnfe;
        } catch (IOException ioe) {
            // May be expected when working with a trust store
            // Re-throw. Caller will catch and log as required
            throw ioe;
        } catch (Exception ex) {
            String msg = sm.getString("jsse.keystore_load_failed", type, path,
                    ex.getMessage());
            log.error(msg, ex);
            throw new IOException(msg);
        } finally {
            if (in != null) {
                try {
                    in.close();
                } catch (IOException ioe) {
                    // Do nothing
                }
            }
        }

        return ks;
    }


    @Override
    public void configureSessionContext(SSLSessionContext sslSessionContext) {
        sslSessionContext.setSessionCacheSize(sslHostConfig.getSessionCacheSize());
        sslSessionContext.setSessionTimeout(sslHostConfig.getSessionTimeout());
    }

    @Override
    public String[] getEnabledProtocols() throws IllegalArgumentException {
        return new String[]{"GMSSLv1.1"};
    }

    @Override
    public String[] getEnabledCiphers() throws IllegalArgumentException {
        return new String[]{"GMSSL_ECC_SM4_SM3"};
    }

}

==> gmssl-tomcat-plugin-v8.5.34-0.1.3-20190724.023809-1-sources.jar: com/xdja/pki/gmssl/tomcat/plugin/XDJAJSSEUtil.java <==
package com.xdja.pki.gmssl.tomcat.plugin;

import org.apache.juli.logging.Log;
import org.apache.juli.logging.LogFactory;
import org.apache.tomcat.util.file.ConfigFileLoader;
import org.apache.tomcat.util.net.SSLContext;
import org.apache.tomcat.util.net.SSLHostConfig;
import org.apache.tomcat.util.net.SSLHostConfigCertificate;
import org.apache.tomcat.util.net.SSLUtil;
import org.apache.tomcat.util.res.StringManager;
import org.bouncycastle.jsse.provider.XDJAJsseProvider;

import javax.net.ssl.*;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.security.KeyStore;
import java.security.NoSuchAlgorithmException;
import java.security.NoSuchProviderException;
import java.util.List;

public class XDJAJSSEUtil implements SSLUtil {

    private static final Log log = LogFactory.getLog(XDJAJSSEUtil.class);
    private static final StringManager sm = StringManager.getManager(XDJAJSSEUtil.class);

    private final SSLHostConfigCertificate certificate;
    private final SSLHostConfig sslHostConfig;

    public XDJAJSSEUtil(SSLHostConfigCertificate certificate) {
        this.certificate = certificate;
        this.sslHostConfig = certificate.getSSLHostConfig();
    }

    @Override
    public SSLContext createSSLContext(List<String> negotiableProtocols) throws NoSuchAlgorithmException, NoSuchProviderException {
        return new XDJAJSSEGMSSLContext(sslHostConfig.getSslProtocol());
    }


    @Override
    public KeyManager[] getKeyManagers() throws Exception {
        String password = this.sslHostConfig.getCertificateKeystorePassword();

        KeyStore ks = getStore(
                this.sslHostConfig.getCertificateKeystoreType(),
                this.sslHostConfig.getCertificateKeystoreProvider(),
                this.sslHostConfig.getCertificateKeystoreFile(),
                password
        );

        KeyManagerFactory keyMgrFact = KeyManagerFactory.getInstance("PKIX", XDJAJsseProvider.PROVIDER_NAME);
        keyMgrFact.init(ks, password.toCharArray());

        return keyMgrFact.getKeyManagers();
    }


    @Override
    public TrustManager[] getTrustManagers() throws Exception {
        KeyStore ts = getStore(
                this.sslHostConfig.getTruststoreType(),
                this.sslHostConfig.getTruststoreProvider(),
                this.sslHostConfig.getTruststoreFile(),
                this.sslHostConfig.getTruststorePassword()
        );

        TrustManagerFactory trustMgrFact = TrustManagerFactory.getInstance("PKIX", XDJAJsseProvider.PROVIDER_NAME);
        trustMgrFact.init(ts);

        return trustMgrFact.getTrustManagers();
    }

    /*
     * Gets the key- or truststore with the specified type, path, and password.
     */
    private KeyStore getStore(String type, String provider, String path, String pass) throws IOException {
        KeyStore ks = null;
        InputStream in = null;
        try {
            if (provider == null) {
                ks = KeyStore.getInstance(type);
            } else {
                ks = KeyStore.getInstance(type, provider);
            }
            in = ConfigFileLoader.getInputStream(path);
            char[] storePass = null;
            if (pass != null && !"".equals(pass)) {
                storePass = pass.toCharArray();
            }
            ks.load(in, storePass);

        } catch (FileNotFoundException fnfe) {
            log.error(sm.getString("jsse.keystore_load_failed", type, path,
                    fnfe.getMessage()), fnfe);
            throw fnfe;
        } catch (IOException ioe) {
            // May be expected when working with a trust store
            // Re-throw. Caller will catch and log as required
            throw ioe;
        } catch (Exception ex) {
            String msg = sm.getString("jsse.keystore_load_failed", type, path,
                    ex.getMessage());
            log.error(msg, ex);
            throw new IOException(msg);
        } finally {
            if (in != null) {
                try {
                    in.close();
                } catch (IOException ioe) {
                    // Do nothing
                }
            }
        }

        return ks;
    }


    @Override
    public void configureSessionContext(SSLSessionContext sslSessionContext) {
        sslSessionContext.setSessionCacheSize(sslHostConfig.getSessionCacheSize());
        sslSessionContext.setSessionTimeout(sslHostConfig.getSessionTimeout());
    }

    @Override
    public String[] getEnabledProtocols() throws IllegalArgumentException {
        return new String[]{"GMSSLv1.1"};
    }

    @Override
    public String[] getEnabledCiphers() throws IllegalArgumentException {
        return new String[]{"GMSSL_ECC_SM4_SM3"};
    }

}
